@@ -823,6 +823,54 @@ vmod_db_execute(
     }
 }
 
+/******************************************************************************
+ * .easy_execute();
+ *****************************************************************************/
+
+#define HANDLE_ARG(N)                                               \
+    if (args->valid_cmd_arg ## N) {                                 \
+        vmod_db_push(ctx, db, args->task_priv, args->cmd_arg ## N); \
+    }
+
+/* we need this twice, with two different arg structures:
+ * - one exposed directly by the vcc
+ * - the other will be used by the proxied version
+ * and sadly we can't use VMOD_PROXIED_METHOD because of this
+ */
+
+#define EASY_EXEC(name, arg_type)                                            \
+VCL_VOID                                                                     \
+name(                                                                        \
+    VRT_CTX, struct vmod_redis_db *db,                                       \
+    struct arg_type *args)                                                   \
+{                                                                            \
+    AN(ctx);                                                                 \
+    AN(db);                                                                  \
+    AN(args);                                                                \
+    AN(args->vcl_priv);                                                      \
+    AN(args->task_priv);                                                     \
+                                                                             \
+    vmod_db_command(ctx, db, args->task_priv, args->command);                \
+    HANDLE_ARG(1);   HANDLE_ARG(2);   HANDLE_ARG(3);   HANDLE_ARG(4);        \
+    HANDLE_ARG(5);   HANDLE_ARG(6);   HANDLE_ARG(7);   HANDLE_ARG(8);        \
+    HANDLE_ARG(9);   HANDLE_ARG(10);  HANDLE_ARG(11);  HANDLE_ARG(12);       \
+    HANDLE_ARG(13);  HANDLE_ARG(14);  HANDLE_ARG(15);  HANDLE_ARG(16);       \
+                                                                             \
+    if (args->valid_timeout) {                                               \
+        vmod_db_timeout(ctx, db, args->task_priv, args->timeout);            \
+    }                                                                        \
+    if (args->valid_retries) {                                               \
+        vmod_db_retries(ctx, db, args->task_priv, args->retries);            \
+    }                                                                        \
+                                                                             \
+    vmod_db_execute(ctx, db, args->vcl_priv, args->task_priv, args->master); \
+}
+
+EASY_EXEC(vmod_db_easy_execute, arg_vmod_redis_db_easy_execute);
+EASY_EXEC(vmod_db_easy_execute_proxy, arg_vmod_redis_easy_execute);
+
+#undef HANDLE_ARG
+
 /******************************************************************************
  * .replied();
  *****************************************************************************/
@@ -1262,7 +1310,7 @@ vmod_db_stats(
     if (stream) {
         result = WS_Copy(ctx->ws, "", -1);
     } else {
-        VSB_putc(vsb, '\0');
+        AZ(VSB_putc(vsb, '\0'));
         AZ(VSB_finish(vsb));
         result = WS_Copy(ctx->ws, VSB_data(vsb), VSB_len(vsb));
         VSB_destroy(&vsb);
@@ -1379,6 +1427,34 @@ vmod_use(
     }
 }
 
+VCL_VOID
+vmod_easy_execute(VRT_CTX, struct arg_vmod_redis_easy_execute *args)
+{
+    struct vmod_redis_db *instance;
+
+    AN(ctx);
+    AN(args);
+    AN(args->vcl_priv);
+    AN(args->task_priv);
+
+    if ((args->db != NULL) && (strlen(args->db) > 0)) {
+        vcl_state_t *config = args->vcl_priv->priv;
+        instance = get_db_instance(ctx, config, args->db);
+    } else {
+        task_state_t *state = get_task_state(ctx, args->task_priv, 0);
+        instance = state->db;
+    }
+
+    if (instance != NULL) {
+        return vmod_db_easy_execute_proxy(ctx, instance, args);
+    } else {
+        REDIS_LOG_ERROR(ctx,
+            "Database instance not available%s",
+            "");
+        return;
+    }
+}
+
 #define _COMMA_ ,
 
 #define VMOD_PROXIED_METHOD(type, fallback, method, margs, fargs...) \
